#
# spec file for package tuba
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appname dev.geopjr.Tuba
Name:           tuba
Version:        0.8.1
Release:        1.1
Summary:        Browse the Fediverse
License:        GPL-3.0-only
URL:            https://github.com/GeopJr/Tuba
Source0:        %{url}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  appstream-glib
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  git-core
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson >= 0.56
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.48
BuildRequires:  pkgconfig(gee-0.8) >= 0.8.5
BuildRequires:  pkgconfig(gtksourceview-5)
BuildRequires:  pkgconfig(json-glib-1.0) >= 1.4.4
BuildRequires:  pkgconfig(libadwaita-1) >= 1.5
BuildRequires:  pkgconfig(libsecret-1) >= 0.20
BuildRequires:  pkgconfig(libsoup-3.0) >= 3.0.0
BuildRequires:  pkgconfig(libspelling-1)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.9.10

%lang_package

%description
%{summary}.

%prep
%autosetup -n Tuba-%{version}

%build
%make_build release=1

%install
%make_install
%find_lang %{appname}
%suse_update_desktop_file %{appname}

%check
%make_build test

%files
%license LICENSE
%doc CODE_OF_CONDUCT.md README.md
%{_bindir}/%{appname}
%{_datadir}/applications/%{appname}.desktop
%{_datadir}/glib-2.0/schemas/dev.geopjr.Tuba.gschema.xml
%{_datadir}/gtksourceview-5/language-specs/fedi-*.lang
%{_datadir}/gtksourceview-5/styles/fedi*
%{_iconsdir}/hicolor/scalable/apps/%{appname}.svg
%{_iconsdir}/hicolor/symbolic/apps/%{appname}-symbolic.svg
%{_mandir}/man1/%{appname}.1.gz
%{_datadir}/metainfo/%{appname}.metainfo.xml

%files lang -f %{appname}.lang

%changelog
* Sun Jun 23 2024 Richard Rahl <rrahl0@disroot.org>
- update to version 0.8.1:
  * gsettings options to disable graphics offload in runtime, in case it crashes
  * Media Viewer gestures requiring an extra click sometimes to work
  * Media Viewer images not being marked as loaded
* Sat Jun 22 2024 Richard Rahl <rrahl0@disroot.org>
- update to version 0.8.0:
  * Admin Dashboard
  * Advanced Search Dialog
  * Ability to dim non-trivial notifications like favorites and boosts
  * Notification clearing
  * Notification filtering
  * Notification requests
  * In-app proxy settings
  * Optional Clapper support
  * Replaced the Media Viewer headerbar with a floating button on fullscreen
  * Reactive relationship updates
  * 'Replying to older post' reminder switch in settings
  * Preview card redesign into a vertical layout
  * Use different icons per view for their empty state status
  * New account window settings
  * Crossed out boost icon when disabled
  * Custom aria labels that contain a summary of the containers
  * Set default poll expiration date to 1 day if available
  * Link opening optimizations
  * Open web+ap links in-app
  * Notify about new sign ups and new reports for admins
  * Notify about severed relationships
  * Post translations when possible
  * Mini profiles on avatar click
  * Profile notes
  * Blocked-by relationship status
  * Network monitoring and graceful recover
  * Profile fields redesign
  * Media Viewer videos will remember the last volume set between restarts
  * GraphicsOffload for Media Viewer videos
  * Profile fields custom emojis
  * In-reply indicator
  * Account Switcher rows using markup
  * Bundle icons that are either missing or have lost their meaning in Breeze/Yaru
  * Snap CI for x86-64 and GNOME 46 sdk
  * Multiple bulk-relationship requests due to multiple content-changed triggers
  * Duplicate posts in 'Home' due to race conditions
  * High-contrast theme borders on profile fields
  * Libsoup not respecting cache and instead re-downloading emojis when it shouldn't
  * Refactored the Custom Emoji Picker to use custom widgets
  * Completion provider capturing
  * Removed all optional chaining instances
  * Scale revealer measuring
  * Focus grabbing of links in labels
  * Segfault when closing the composer quickly due to a dispose hack
  * Min width due to strict headerbar centering policy
  * Segfault when inspecting labels with widgets due to infinite loop of a property
  * Singular and plural versions of some counters
  * Accessibility of icons
  * Better aria labels for dates
  * Missing tooltips
  * Accessibility of containers
  * Accessibility of custom widgets
  * Lower height request so it fits with OSK
  * Stricter resolvable link detection rules
  * Stricter hashtag url matching when clicking a link
  * Many random segfaults when going back caused by a disposing hack
  * Hiding inline quotes when there's no actual quote and the class wasn't sanitized
  * Composer highlighting hashtags accepting invalid characters
  * Composer highlighting being too loose on whole word matching
  * Horizontal swiping on the Media Viewer
  * Crash when opening the composer while the instance doesn't have custom emojis due to optional chaining
  * Some strings not being marked for translations
  * Other bug and memory leak fixes
* Sun Apr 21 2024 Richard Rahl <rrahl0@disroot.org>
- initial packaging
